@@ -2,13 +2,13 @@
 #'
 #' @export
 #' @template dframe1
-#' @param type (character) One place type name. See \code{\link{mr_place_types}} for
-#' place type names
+#' @param type (character) One place type name. See
+#' \code{\link{mr_place_types}} for place type names
 #' @param offset (numeric) Offset to start at. Each request can return up to
 #' 100 results. e.g., an offset of 200 will give records 200 to 299.
 #' @param ... Curl options passed on to \code{\link[httr]{GET}}
-#' @details Internally we use the \code{getGazetteerRecordsByType.json} API method,
-#' which searches for Marineregions records by user supplied place type
+#' @details Internally we use the \code{getGazetteerRecordsByType.json} API
+#' method, which searches for Marineregions records by user supplied place type
 #' @examples \dontrun{
 #' # Get records of type 'EEZ', then inspect data.frame
 #' res <- mr_records_by_type(type="EEZ")
@@ -29,7 +29,9 @@
 #' }
 mr_records_by_type <- function(type, offset = 0, ...) {
   stopifnot(is.numeric(offset) || is.integer(offset))
-  url <- utils::URLencode(file.path(mr_base(), 'getGazetteerRecordsByType.json', type, offset, '/'))
+  url <- utils::URLencode(
+    file.path(mr_base(),
+              'getGazetteerRecordsByType.json', type, offset, '/'))
   x <- getter(url, args = NULL,
     format = "application/json; charset=UTF-8;", ...
   )
